@@ -1,6 +1,6 @@
 #include <stdio.h>
 
-static char version[] = "0.0.15 beta";
+static char version[] = "0.0.18 beta";
 
 // 関数プロトタイプ
 void help(void);
@@ -15,12 +15,8 @@ void help()
 	puts("floder内のファイルをデフラグする。folderは複数指定可能。");
 	puts("");
 	puts("オプション");
-	puts(" -a    デフラグの成功率を向上させる。");
-	puts("");
 	puts(" -g    1GBを超えるファイルもデフラグの対象にする。");
 	puts("");
 	puts(" -G    1GBを超えるファイルのみをデフラグの対象にする。");
 	puts("");
-	puts(" -r    ベリファイを行う。");
-	puts("");
 }
